#!/bin/bash
#PBS -q C064
#PBS -P teqt-st2
#PBS -o outfile
#PBS -e errfile
#PBS -V

# シェルスクリプトの説明
# 例題ex01を実行します。 (防災情報イノベーションプラットフォームIntel/CPU計算)


## Please set library path.

# GDAL_PATH=/usr/local/gdal-1.11.4/lib
# XERCES_PATH=/usr/local/xerces-c-3.1.2/lib
# CUDA_PATH=/usr/local/cuda-7.5/lib64

GDAL_PATH=/data04/teqt-st2/TNS/LIB/gdal-1.11/lib
XERCES_PATH=/data04/teqt-st2/TNS/LIB/xerces-c-3.1/lib
PROJ4_PATH=/data04/teqt-st2/TNS/LIB/proj.4-4.9.2/lib
NETCDF4_PATH=/cm/shared/apps/netcdf-c/4.3.3/gcc/4.8.5/lib
cd ${PBS_O_WORKDIR}

# Set ex01.xml Directory
pro=ex01
DEST_DIR=${pro}/DEST
OUTPUT_DIR=${pro}/OUTPUT

EPSG=3100
# EPSG=2446
sponge=0

export LD_LIBRARY_PATH=${GDAL_PATH}:${XERCES_PATH}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH=${PROJ4_PATH}:${NETCDF4_PATH}:${LD_LIBRARY_PATH}
#export LD_LIBRARY_PATH=${CUDA_PATH}:${LD_LIBRARY_PATH}
export OMP_NUM_THREADS=1

EXE_DIR=../bin/Intel

# ConfMaker
${EXE_DIR}/ConfMaker ${pro}.xml

# IWHMaker
${EXE_DIR}/IWHMaker IWHConf_${pro}.txt

# bin2tiff
COLOR=./DATA/colormapZ.dat
for bin in ${DEST_DIR}/VRT_*_0000s.bin ${DEST_DIR}/IWH_*_0000s.bin; do ${EXE_DIR}/bin2tiff ${COLOR} ${EPSG} ${sponge} ${bin} ${bin/.bin/_001m}; done

# tns-solver_gpu
${EXE_DIR}/tns-solver CalcParameter_${pro}.txt

# bin2tiff
for Z in ${OUTPUT_DIR}/Z01_t??????.bin;do ${EXE_DIR}/bin2tiff ${COLOR} ${EPSG} ${sponge} ${Z} ${Z/.bin/sec_001m};done
for Z in ${OUTPUT_DIR}/ZMAX01.bin;     do ${EXE_DIR}/bin2tiff ${COLOR} ${EPSG} ${sponge} ${Z} ${Z/.bin/_001m};done
for Z in ${OUTPUT_DIR}/Z02_t??????.bin;do ${EXE_DIR}/bin2tiff ${COLOR} ${EPSG} ${sponge} ${Z} ${Z/.bin/sec_001m};done
for Z in ${OUTPUT_DIR}/ZMAX02.bin;     do ${EXE_DIR}/bin2tiff ${COLOR} ${EPSG} ${sponge} ${Z} ${Z/.bin/_001m};done

# bin2netCDF4
for Z in ${OUTPUT_DIR}/Z01_t??????.bin;do ${EXE_DIR}/bin2netCDF4 ${EPSG} ${sponge} ${Z} ${Z/.bin/sec};done
for Z in ${OUTPUT_DIR}/ZMAX01.bin;     do ${EXE_DIR}/bin2netCDF4 ${EPSG} ${sponge} ${Z} ${Z/.bin/};done
for Z in ${OUTPUT_DIR}/Z02_t??????.bin;do ${EXE_DIR}/bin2netCDF4 ${EPSG} ${sponge} ${Z} ${Z/.bin/sec};done
for Z in ${OUTPUT_DIR}/ZMAX02.bin;     do ${EXE_DIR}/bin2netCDF4 ${EPSG} ${sponge} ${Z} ${Z/.bin/};done

# dump1d2ascii
${EXE_DIR}/dump1d2ascii Z ${OUTPUT_DIR}/Dump1dUni_Z.bin ${OUTPUT_DIR}/Dump1dUni_Z.dat
${EXE_DIR}/dump1d2ascii D ${OUTPUT_DIR}/Dump1dUni_D.bin ${OUTPUT_DIR}/Dump1dUni_D.dat
${EXE_DIR}/dump1d2ascii M ${OUTPUT_DIR}/Dump1dUni_M.bin ${OUTPUT_DIR}/Dump1dUni_M.dat
${EXE_DIR}/dump1d2ascii N ${OUTPUT_DIR}/Dump1dUni_N.bin ${OUTPUT_DIR}/Dump1dUni_N.dat


